@@ -63,6 +63,7 @@ std::string Foundation_API format(const std::string& fmt, const Any& value);
 	///   * E signed floating-point value in the form [-]d.ddddE[<sign>]dd[d]
 	///   * f signed floating-point value in the form [-]dddd.dddd
 	///   * s std::string
+	///   * v std::string_view
 	///   * z std::size_t
 	///
 	/// The following flags are supported:
@@ -115,14 +116,14 @@ inline void formatAny(std::string& result, const std::string& fmt, const std::ve
 	/// Supports a variable number of arguments and is used by
 	/// all other variants of format().
 {
-	format(result, fmt, values);
+	Poco::format(result, fmt, values);
 }
 
 inline void formatAny(std::string& result, const char *fmt, const std::vector<Any>& values)
 	/// Supports a variable number of arguments and is used by
 	/// all other variants of format().
 {
-	format(result, fmt, values);
+	Poco::format(result, fmt, values);
 }
 
 template <typename T, typename... Args>
